@@ -17,8 +17,11 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
---   For the latest information, source code (SVN), releases, bug and feature
---   request tracking go to:
+--   For the latest information, source code (SVN), releases, and bug tracking
+--   go to:
+--      http://savannah.nongnu.org/projects/objectify
+--
+--   For releases from Alpha_30 and up, bug and feature request tracking go to:
 --      http://sourceforge.net/projects/objectify
 --
 --   For older bug tracking, releases and source code (CVS) prior to the
@@ -36,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2009-08-02 10:09:28 -0600 (Sun, 02 Aug 2009) $
---   $Revision: 4235 $
+--   $Date: 2010-01-23 08:06:10 -0700 (Sat, 23 Jan 2010) $
+--   $Revision: 4485 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -46,6 +49,8 @@
 --
 */
 
+#ifndef PUBLIC_MODE    /* shouldn't need bit maps in public mode */
+
 #include <assert.h>
 #include <stdlib.h>    /* define NULL */
 #include <string.h>    /* define memcmp */
@@ -651,3 +656,5 @@ void nwos_calculate_chunk_md5sum(uint32 chunk_index, uint8 md5_digest[MD5_DIGEST
 }
 
 
+#endif  /* ifndef PUBLIC_MODE */
+
