@@ -17,8 +17,11 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
---   For the latest information, source code (SVN), releases, bug and feature
---   request tracking go to:
+--   For the latest information, source code (SVN), releases, and bug tracking
+--   go to:
+--      http://savannah.nongnu.org/projects/objectify
+--
+--   For releases from Alpha_30 and up, bug and feature request tracking go to:
 --      http://sourceforge.net/projects/objectify
 --
 --   For older bug tracking, releases and source code (CVS) prior to the
@@ -36,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2009-08-01 08:34:47 -0600 (Sat, 01 Aug 2009) $
---   $Revision: 4227 $
+--   $Date: 2010-01-22 18:47:06 -0700 (Fri, 22 Jan 2010) $
+--   $Revision: 4479 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -66,6 +69,8 @@
 
 /* Warning: if the total_number_of_chunks changes, all of these have to be reallocated. */
 
+#ifndef PUBLIC_MODE
+
 Chunk_Info*    nwos_chunk_info;
 
 static int*    chunk_info_reverse_index;   /* index from chunk index to info table */
@@ -75,7 +80,6 @@ static uint32 capacity;
 static bool chunk_info_modified;
 
 
-
 /*************************************************************************************/
 /* This updates the chunk_info_reverse_index table to point to the chunk_info table. */
 /*                                                                                   */
@@ -416,7 +420,6 @@ int nwos_chunk_index_to_info_index(uint16 chunk_index)
 /* -1 if not found.                                                                           */
 /**********************************************************************************************/
 
-#ifndef PUBLIC_MODE
 int nwos_uint64_ref_to_info_index(uint64 ref)
 {
     int lwr;
@@ -559,7 +562,6 @@ void nwos_clear_chunk_digest(ObjRef* ref)
 
     memset(nwos_chunk_info[info_index].md5_digest, 0, sizeof(nwos_chunk_info[info_index].md5_digest));
 }
-#endif
 
 
 /*************************************/
@@ -651,4 +653,5 @@ void nwos_allocate_new_chunk(uint32 uint32_ref)
     chunk_info_modified = true;
 }
 
+#endif
 
