@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2010-01-23 08:16:41 -0700 (Sat, 23 Jan 2010) $
---   $Revision: 4488 $
+--   $Date: 2010-02-10 06:16:11 -0700 (Wed, 10 Feb 2010) $
+--   $Revision: 4559 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -182,14 +182,14 @@ const char* nwos_load_private_data(void* buffer, size_t buffer_size, bool compre
 }
 
 
-void nwos_store_private_data(void* buffer, size_t buffer_size, bool archive_is_file)
+void nwos_store_private_data(void* buffer, size_t buffer_size, bool update_total_chunks)
 {
     uint32 total_private_chunks;
 
     nwos_uint64_to_8_uint8(&nwos_used_private_blocks, nwos_private_disk_header.used_blocks);
     nwos_uint32_to_4_uint8(&nwos_used_private_chunks, nwos_private_disk_header.used_chunks);
 
-    if (archive_is_file)   /* totals could have changed */
+    if (update_total_chunks)   /* totals could have changed */
     {
 	nwos_uint32_to_4_uint8(&nwos_total_private_chunks, nwos_private_disk_header.total_chunks);
     }
