@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2009-10-17 20:11:38 -0600 (Sat, 17 Oct 2009) $
---   $Revision: 4393 $
+--   $Date: 2010-02-10 06:16:11 -0700 (Wed, 10 Feb 2010) $
+--   $Revision: 4559 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -154,7 +154,7 @@ extern const char* nwos_check_disk_header(Disk_Header* disk_header, bool compres
 extern const char* nwos_load_public_data(void *buffer, size_t buffer_size);
 extern void nwos_store_public_data(void *buffer, size_t buffer_size);
 extern const char* nwos_load_private_data(void *buffer, size_t buffer_size, bool compressed_file);
-extern void nwos_store_private_data(void *buffer, size_t buffer_size, bool archive_is_file);
+extern void nwos_store_private_data(void *buffer, size_t buffer_size, bool update_total_chunks);
 
 
 #endif
