@@ -1,6 +1,6 @@
 /*
 --          This file is part of the New World OS and Objectify projects
---            Copyright (C) 2005, 2006, 2007, 2008, 2009  QRW Software
+--         Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010  QRW Software
 --               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
@@ -39,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2009-10-06 08:06:23 -0600 (Tue, 06 Oct 2009) $
---   $Revision: 4384 $
+--   $Date: 2010-02-04 06:13:27 -0700 (Thu, 04 Feb 2010) $
+--   $Revision: 4534 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -78,7 +78,9 @@
 #define NUM_STORED_SEQ 4096     /* number of sequence tables that are stored, 4096 = 1 MB worth and uses 1 MB worth of RAM */
 
 
-#ifndef PUBLIC_MODE
+#ifdef PUBLIC_MODE
+#define DISABLE_SECURITY_FEATURES
+#else
 static uint32 linear_after_first;
 static uint32 serial_after_first;
 
@@ -87,6 +89,7 @@ static uint8  nwos_random_sequence[NUM_STORED_SEQ][FILE_BLOCK_SIZE];     /* this
 static BF_KEY blowfish_key;
 #endif
 
+#ifndef DISABLE_SECURITY_FEATURES
 
 static uint32 nwos_next_sequence(uint32* linear, uint32* serial)
 {
@@ -104,7 +107,37 @@ static uint32 nwos_next_sequence(uint32* linear, uint32* serial)
 }
 
 
-void convert_pass_phrase_to_reference(char* pass_phrase, uint8 key[], size_t key_size)
+/**********************/
+/* Sequence generator */
+/**********************/
+
+static void generate_sequence_table(uint32* linear, uint32* serial, uint8 table[FILE_BLOCK_SIZE])
+{
+    int i;
+    uint8 j;
+    uint8 filled[FILE_BLOCK_SIZE];    /* remember which slots are already filled */
+
+    /* mark all slots as empty */
+    for (i = 0; i < FILE_BLOCK_SIZE; i++) filled[i] = 0;
+
+    /* then mark the first 8 as used */
+    for (i = 0; i < 8; i++) filled[i] = 1;
+
+    /* start at 0 because it is used already, so while loop will fail the first time. */
+    j = 0;
+    assert(filled[j] != 0);
+
+    for (i = 8; i < FILE_BLOCK_SIZE; i++)
+    {
+	/* find where the next byte is stored */
+	while(filled[j] != 0) j = nwos_next_sequence(linear, serial) % FILE_BLOCK_SIZE;
+	table[i] = j;   /* store it in the table */
+	filled[j] = 1;            /* mark it as used */
+    }
+}
+
+
+static void convert_pass_phrase_to_reference(char* pass_phrase, uint8 key[], size_t key_size)
 {
     int i;
     int j;
@@ -166,9 +199,8 @@ void convert_pass_phrase_to_reference(char* pass_phrase, uint8 key[], size_t key
 }
 
 
-void convert_short_pass_phrase_to_reference(char* pass_phrase, uint8 key[], size_t key_size)
+static void convert_short_pass_phrase_to_reference(char* pass_phrase, uint8 key[], size_t key_size)
 {
-#ifndef PUBLIC_MODE
     int i;
     int j;
     uint8 number[SHORT_NUMBER_SIZE];
@@ -246,7 +278,6 @@ void convert_short_pass_phrase_to_reference(char* pass_phrase, uint8 key[], size
 	j++;
 	if (j == key_size) j = 0;
     }
-#endif
 }
 
 
@@ -475,39 +506,6 @@ void nwos_get_key_from_password(uint8 key[], size_t key_size)
 
 
 
-/**********************/
-/* Sequence generator */
-/**********************/
-
-#ifndef PUBLIC_MODE
-static void generate_sequence_table(uint32* linear, uint32* serial, uint8 table[FILE_BLOCK_SIZE])
-{
-    int i;
-    uint8 j;
-    uint8 filled[FILE_BLOCK_SIZE];    /* remember which slots are already filled */
-
-    /* mark all slots as empty */
-    for (i = 0; i < FILE_BLOCK_SIZE; i++) filled[i] = 0;
-
-    /* then mark the first 8 as used */
-    for (i = 0; i < 8; i++) filled[i] = 1;
-
-    /* start at 0 because it is used already, so while loop will fail the first time. */
-    j = 0;
-    assert(filled[j] != 0);
-
-    for (i = 8; i < FILE_BLOCK_SIZE; i++)
-    {
-	/* find where the next byte is stored */
-	while(filled[j] != 0) j = nwos_next_sequence(linear, serial) % FILE_BLOCK_SIZE;
-	table[i] = j;   /* store it in the table */
-	filled[j] = 1;            /* mark it as used */
-    }
-}
-#endif
-
-
-#ifndef PUBLIC_MODE
 void nwos_setup_from_big_key(uint8 big_key[16 + 8 + 4], ObjRef* root_object_ref)
 {
     int i;
