@@ -39,8 +39,8 @@
 #      Salt Lake City, UT 84127-0511, USA.
 #
 #   $Author: jsedwards $
-#   $Date: 2010-01-30 08:57:28 -0700 (Sat, 30 Jan 2010) $
-#   $Revision: 4510 $
+#   $Date: 2010-02-28 10:02:07 -0700 (Sun, 28 Feb 2010) $
+#   $Revision: 4604 $
 #
 #   NOTE: Subversion does not support the Log keyword so I have removed the
 #   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -393,10 +393,13 @@ if ! $EXEC/src/apps/util/compressed-diff /tmp/objectify_test/compressed-after /t
    exit 1
 fi
 
-echo "PLEASE check above that there were no differences!"
+echo ""
+echo "*****   PLEASE check above that there were no differences!   *****"
+echo ""
 
-sleep 5
+sleep 10
 
+echo ""
 
 echo "---------------------------"
 echo " prep a third archive..."
@@ -451,9 +454,13 @@ if ! $EXEC/src/apps/util/compressed-diff /tmp/objectify_test/compressed-after /t
    exit 1
 fi
 
-echo "PLEASE check above that there were no differences!"
+echo ""
+echo "*****   PLEASE check above that there were no differences!   *****"
+echo ""
 
-sleep 5
+sleep 10
+
+echo ""
 
 
 echo "---------------------------"
@@ -560,9 +567,9 @@ echo "-----------------------------------------------"
 export OBJECTIFY_PRIVATE_PATH=/tmp/objectify_test/private.obj
 export OBJECTIFY_TEST_ONLY_DO_NOT_USE="Diff Compressed Test Too"
 
-if ! $EXEC/src/apps/util/archive-add-zone; then
+if ! $EXEC/src/apps/util/zone-add; then
    echo ""
-   echo "archive-add-zone failed"
+   echo "zone-add failed"
    echo ""
    exit 1
 fi
