@@ -1,6 +1,6 @@
 #
 #          This file is part of the New World OS and Objectify projects
-#                     Copyright (C) 2008, 2009  QRW Software
+#                  Copyright (C) 2008, 2009, 2010  QRW Software
 #               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -17,8 +17,11 @@
 #   along with this program, in the file LICENSE.  If not, see 
 #   <http://www.gnu.org/licenses/>.
 #
-#   For the latest information, source code (SVN), releases, bug and feature
-#   request tracking go to:
+#   For the latest information, source code (SVN), releases, and bug tracking
+#   go to:
+#      http://savannah.nongnu.org/projects/objectify
+#
+#   For releases from Alpha_30 and up, bug and feature request tracking go to:
 #      http://sourceforge.net/projects/objectify
 #
 #   For older bug tracking, releases and source code (CVS) prior to the
@@ -36,8 +39,8 @@
 #      Salt Lake City, UT 84127-0511, USA.
 #
 #   $Author: jsedwards $
-#   $Date: 2009-09-20 13:04:12 -0600 (Sun, 20 Sep 2009) $
-#   $Revision: 4372 $
+#   $Date: 2010-01-30 08:57:28 -0700 (Sat, 30 Jan 2010) $
+#   $Revision: 4510 $
 #
 #   NOTE: Subversion does not support the Log keyword so I have removed the
 #   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -104,9 +107,9 @@ echo "------------------"
 
 echo $OBJECTIFY_PRIVATE_PATH
 
-if ! $EXEC/src/apps/util/prep_archive; then
+if ! $EXEC/src/apps/util/archive-prep; then
    echo ""
-   echo "prep_archive failed"
+   echo "archive-prep failed"
    echo ""
    exit 1
 fi
@@ -117,28 +120,28 @@ echo "------------------------------------------------------------------"
 echo " test that programs fail when there are no files in the system..."
 echo "------------------------------------------------------------------"
 
-if $EXEC/src/apps/file/import_file test1.txt; then
+if $EXEC/src/apps/file/file-import test1.txt; then
    echo ""
    echo "import non-existant file succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/src/apps/file/verify_file test1.txt; then
+if $EXEC/src/apps/file/file-verify test1.txt; then
    echo ""
    echo "verify non-existant file succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/src/apps/file/export_file test1.txt; then
+if $EXEC/src/apps/file/file-export test1.txt; then
    echo ""
    echo "export non-existant file succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/src/apps/file/list_files test1.txt; then
+if $EXEC/src/apps/file/file-list test1.txt; then
    echo ""
    echo "list non-existant file succeeded"
    echo ""
@@ -152,9 +155,9 @@ echo "-------------------------"
 
 echo "This is test #1" >> test1.txt
 
-if ! $EXEC/src/apps/file/import_file test1.txt > /tmp/test1.out; then
+if ! $EXEC/src/apps/file/file-import test1.txt > /tmp/test1.out; then
    echo ""
-   echo "import_file failed"
+   echo "file-import failed"
    echo ""
    exit 1
 fi
@@ -166,9 +169,9 @@ if ! grep -q "files created:   1" /tmp/test1.out; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/list_files --md5 test1.txt > test1.md5; then
+if ! $EXEC/src/apps/file/file-list --md5 test1.txt > test1.md5; then
    echo ""
-   echo "list_files --md5 failed"
+   echo "file-list --md5 failed"
    echo ""
    exit 1
 fi
@@ -180,9 +183,9 @@ if ! md5sum -c test1.md5; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/list_files --sha1 test1.txt > test1.sha1; then
+if ! $EXEC/src/apps/file/file-list --sha1 test1.txt > test1.sha1; then
    echo ""
-   echo "list_files --sha1 failed"
+   echo "file-list --sha1 failed"
    echo ""
    exit 1
 fi
@@ -194,9 +197,9 @@ if ! sha1sum -c test1.sha1; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/list_files --sha256 test1.txt > test1.sha256; then
+if ! $EXEC/src/apps/file/file-list --sha256 test1.txt > test1.sha256; then
    echo ""
-   echo "list_files --sha256 failed"
+   echo "file-list --sha256 failed"
    echo ""
    exit 1
 fi
@@ -208,9 +211,9 @@ if ! sha256sum -c test1.sha256; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/list_files --sha512 test1.txt > test1.sha512; then
+if ! $EXEC/src/apps/file/file-list --sha512 test1.txt > test1.sha512; then
    echo ""
-   echo "list_files --sha512 failed"
+   echo "file-list --sha512 failed"
    echo ""
    exit 1
 fi
@@ -222,30 +225,30 @@ if ! sha512sum -c test1.sha512; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/verify_file test1.txt; then
+if ! $EXEC/src/apps/file/file-verify test1.txt; then
    echo ""
-   echo "verify_file failed"
+   echo "file-verify failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/verify_file --remove-no-shred test1.txt; then
+if ! $EXEC/src/apps/file/file-verify --remove-no-shred test1.txt; then
    echo ""
-   echo "verify_file failed"
+   echo "file-verify failed"
    echo ""
    exit 1
 fi
 
-if $EXEC/src/apps/file/verify_file test1.txt; then
+if $EXEC/src/apps/file/file-verify test1.txt; then
    echo ""
    echo "verify non-existant file succeeded"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/export_file test1.txt; then
+if ! $EXEC/src/apps/file/file-export test1.txt; then
    echo ""
-   echo "export_file failed"
+   echo "file-export failed"
    echo ""
    exit 1
 fi
@@ -291,9 +294,9 @@ if ! touch test1.txt; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/import_file test1.txt > /tmp/test1.out; then
+if ! $EXEC/src/apps/file/file-import test1.txt > /tmp/test1.out; then
    echo ""
-   echo "import_file failed"
+   echo "file-import failed"
    echo ""
    exit 1
 fi
@@ -305,28 +308,28 @@ if ! grep -q "existing files:  1" /tmp/test1.out; then
    exit 1
 fi
 
-if $EXEC/src/apps/file/verify_file test1.txt; then
+if $EXEC/src/apps/file/file-verify test1.txt; then
    echo ""
    echo "verify file with different time stamp succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/src/apps/file/verify_file --remove-no-shred test1.txt; then
+if $EXEC/src/apps/file/file-verify --remove-no-shred test1.txt; then
    echo ""
    echo "verify file --remove with different time stamp succeeded"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/verify_file --ignore-time test1.txt; then
+if ! $EXEC/src/apps/file/file-verify --ignore-time test1.txt; then
    echo ""
    echo "verify file with --ignore-time failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/verify_file --ignore-time --remove-no-shred test1.txt; then
+if ! $EXEC/src/apps/file/file-verify --ignore-time --remove-no-shred test1.txt; then
    echo ""
    echo "verify file --remove --ignore-time failed"
    echo ""
@@ -339,28 +342,28 @@ echo "-----------------------------------------------------------"
 echo " test that programs fail when file isn't in the system..."
 echo "-----------------------------------------------------------"
 
-if $EXEC/src/apps/file/import_file test2.txt; then
+if $EXEC/src/apps/file/file-import test2.txt; then
    echo ""
    echo "import non-existant file succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/src/apps/file/verify_file test2.txt; then
+if $EXEC/src/apps/file/file-verify test2.txt; then
    echo ""
    echo "verify non-existant file succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/src/apps/file/export_file test2.txt; then
+if $EXEC/src/apps/file/file-export test2.txt; then
    echo ""
    echo "export non-existant file succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/src/apps/file/list_files test2.txt; then
+if $EXEC/src/apps/file/file-list test2.txt; then
    echo ""
    echo "list non-existant file succeeded"
    echo ""
@@ -374,7 +377,7 @@ echo "---------------------------------------------------"
 
 echo "This is test #1" >> test1diffname.txt
 
-if $EXEC/src/apps/file/import_file test1diffname.txt > /tmp/test1.out; then
+if $EXEC/src/apps/file/file-import test1diffname.txt > /tmp/test1.out; then
    echo ""
    echo "import duplicate file succeeded"
    echo ""
@@ -397,9 +400,9 @@ mkdir subdir
 
 mv -i test1diffname.txt subdir
 
-if ! $EXEC/src/apps/file/import_file -r subdir > /tmp/test1.out; then
+if ! $EXEC/src/apps/file/file-import -r subdir > /tmp/test1.out; then
    echo ""
-   echo "import_file subdir failed"
+   echo "file-import subdir failed"
    echo ""
    exit 1
 fi
@@ -411,37 +414,37 @@ if ! grep -q "new paths:       1" /tmp/test1.out; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/verify_file -r subdir; then
+if ! $EXEC/src/apps/file/file-verify -r subdir; then
    echo ""
-   echo "verify_file subdir failed"
+   echo "file-verify subdir failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/verify_file --remove-no-shred -r subdir; then
+if ! $EXEC/src/apps/file/file-verify --remove-no-shred -r subdir; then
    echo ""
-   echo "verify_file --remove subdir failed"
+   echo "file-verify --remove subdir failed"
    echo ""
    exit 1
 fi
 
-if $EXEC/src/apps/file/verify_file subdir; then
+if $EXEC/src/apps/file/file-verify subdir; then
    echo ""
    echo "verify non-existant file succeeded"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/export_file subdir/*; then
+if ! $EXEC/src/apps/file/file-export subdir/*; then
    echo ""
-   echo "export_file failed"
+   echo "file-export failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/import_file subdir/* > /tmp/test1.out; then
+if ! $EXEC/src/apps/file/file-import subdir/* > /tmp/test1.out; then
    echo ""
-   echo "import_file failed"
+   echo "file-import failed"
    echo ""
    exit 1
 fi
@@ -460,23 +463,23 @@ echo "-------------------------------------------------"
 
 echo "Test #1, has been changed" >> test1.txt
 
-if $EXEC/src/apps/file/verify_file test1.txt; then
+if $EXEC/src/apps/file/file-verify test1.txt; then
    echo ""
-   echo "verify_file revised file succeeded"
+   echo "file-verify revised file succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/src/apps/file/verify_file --remove-no-shred test1.txt; then
+if $EXEC/src/apps/file/file-verify --remove-no-shred test1.txt; then
    echo ""
-   echo "verify_file --remove revised file succeeded"
+   echo "file-verify --remove revised file succeeded"
    echo ""
    exit 1
 fi
 
-if $EXEC/src/apps/file/import_file test1.txt > /tmp/test1r.out; then
+if $EXEC/src/apps/file/file-import test1.txt > /tmp/test1r.out; then
    echo ""
-   echo "import_file revised file without --add-revision succeeded"
+   echo "file-import revised file without --add-revision succeeded"
    echo ""
    exit 1
 fi
@@ -496,16 +499,16 @@ echo "---------------------------"
 mkdir 20081221-909
 echo "Testing import data" >> 20081221-909/test2.txt
 
-if ! $EXEC/src/apps/file/disc_list 20081221-909 <<EOF ; then
+if ! $EXEC/src/apps/file/disc-import 20081221-909 <<EOF ; then
 20081221-909
 EOF
    echo ""
-   echo "disc_list failed"
+   echo "disc-import failed"
    echo ""
    exit 1
 fi
 
-if $EXEC/src/apps/file/export_file test2.txt; then
+if $EXEC/src/apps/file/file-export test2.txt; then
    echo ""
    echo "export file with no data succeeded"
    echo ""
@@ -515,9 +518,9 @@ fi
 mv -i 20081221-909/test2.txt .
 rmdir 20081221-909
 
-if ! $EXEC/src/apps/file/list_files --md5 test2.txt > test2.md5; then
+if ! $EXEC/src/apps/file/file-list --md5 test2.txt > test2.md5; then
    echo ""
-   echo "list_files --md5 failed"
+   echo "file-list --md5 failed"
    echo ""
    exit 1
 fi
@@ -529,9 +532,9 @@ if ! md5sum -c test2.md5; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/list_files --sha1 test2.txt > test2.sha1; then
+if ! $EXEC/src/apps/file/file-list --sha1 test2.txt > test2.sha1; then
    echo ""
-   echo "list_files --sha1 failed"
+   echo "file-list --sha1 failed"
    echo ""
    exit 1
 fi
@@ -543,9 +546,9 @@ if ! sha1sum -c test2.sha1; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/list_files --sha256 test2.txt > test2.sha256; then
+if ! $EXEC/src/apps/file/file-list --sha256 test2.txt > test2.sha256; then
    echo ""
-   echo "list_files --sha256 failed"
+   echo "file-list --sha256 failed"
    echo ""
    exit 1
 fi
@@ -557,9 +560,9 @@ if ! sha256sum -c test2.sha256; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/list_files --sha512 test2.txt > test2.sha512; then
+if ! $EXEC/src/apps/file/file-list --sha512 test2.txt > test2.sha512; then
    echo ""
-   echo "list_files --sha512 failed"
+   echo "file-list --sha512 failed"
    echo ""
    exit 1
 fi
@@ -572,24 +575,24 @@ if ! sha512sum -c test2.sha512; then
 fi
 
 
-if ! $EXEC/src/apps/file/verify_file test2.txt; then
+if ! $EXEC/src/apps/file/file-verify test2.txt; then
    echo ""
-   echo "verify_file failed"
+   echo "file-verify failed"
    echo ""
    exit 1
 fi
 
-if $EXEC/src/apps/file/verify_file --remove-no-shred test2.txt; then
+if $EXEC/src/apps/file/file-verify --remove-no-shred test2.txt; then
    echo ""
-   echo "verify_file --remove no data succeeded"
+   echo "file-verify --remove no data succeeded"
    echo ""
    exit 1
 fi
 
 
-if ! $EXEC/src/apps/file/import_file test2.txt > /tmp/test2i.out; then
+if ! $EXEC/src/apps/file/file-import test2.txt > /tmp/test2i.out; then
    echo ""
-   echo "import_file data failed"
+   echo "file-import data failed"
    echo ""
    exit 1
 fi
@@ -602,22 +605,22 @@ if ! grep -q "imported data:   1" /tmp/test2i.out; then
 fi
 
 
-if ! $EXEC/src/apps/file/verify_file test2.txt; then
+if ! $EXEC/src/apps/file/file-verify test2.txt; then
    echo ""
-   echo "verify_file failed"
+   echo "file-verify failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/verify_file --remove-no-shred test2.txt; then
+if ! $EXEC/src/apps/file/file-verify --remove-no-shred test2.txt; then
    echo ""
-   echo "verify_file --remove failed"
+   echo "file-verify --remove failed"
    echo ""
    exit 1
 fi
 
 
-if ! $EXEC/src/apps/file/export_file test2.txt; then
+if ! $EXEC/src/apps/file/file-export test2.txt; then
    echo ""
    echo "export file failed"
    echo ""
@@ -652,9 +655,9 @@ if ! sha512sum -c test2.sha512; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/verify_file --remove-min-shred test2.txt; then
+if ! $EXEC/src/apps/file/file-verify --remove-min-shred test2.txt; then
    echo ""
-   echo "verify_file --remove-min-shred failed"
+   echo "file-verify --remove-min-shred failed"
    echo ""
    exit 1
 fi
@@ -667,9 +670,9 @@ echo "--------------------------------------"
 
 echo "This is test #1" >> test2.txt
 
-if $EXEC/src/apps/file/import_file test2.txt > /tmp/test2e.out; then
+if $EXEC/src/apps/file/file-import test2.txt > /tmp/test2e.out; then
    echo ""
-   echo "import_file path and file exist succeeded"
+   echo "file-import path and file exist succeeded"
    echo ""
    exit 1
 fi
@@ -682,9 +685,9 @@ if ! grep -q "duplicate files: 1" /tmp/test2e.out; then
 fi
 
 
-if $EXEC/src/apps/file/import_file -r test2.txt > /tmp/test2e.out; then
+if $EXEC/src/apps/file/file-import -r test2.txt > /tmp/test2e.out; then
    echo ""
-   echo "import_file -r path and file exist succeeded"
+   echo "file-import -r path and file exist succeeded"
    echo ""
    exit 1
 fi
@@ -703,9 +706,9 @@ echo "--------------------------------------"
 
 echo "This is test #8" >> test8.txt
 
-if ! $EXEC/src/apps/file/import_file test8.txt > /tmp/test8.out; then
+if ! $EXEC/src/apps/file/file-import test8.txt > /tmp/test8.out; then
    echo ""
-   echo "import_file test8.txt failed"
+   echo "file-import test8.txt failed"
    echo ""
    exit 1
 fi
@@ -714,9 +717,9 @@ sleep 1
 
 cp test8.txt Test8.txt
 
-if $EXEC/src/apps/file/import_file Test8.txt > /tmp/test8.out; then
+if $EXEC/src/apps/file/file-import Test8.txt > /tmp/test8.out; then
    echo ""
-   echo "import_file Test8.txt succeeded"
+   echo "file-import Test8.txt succeeded"
    echo ""
    exit 1
 fi
@@ -729,9 +732,9 @@ if ! grep -q "duplicate files: 1" /tmp/test8.out; then
 fi
 
 
-if ! $EXEC/src/apps/file/import_file -r Test8.txt > /tmp/test8.out; then
+if ! $EXEC/src/apps/file/file-import -r Test8.txt > /tmp/test8.out; then
    echo ""
-   echo "import_file -r Test8.txt failed"
+   echo "file-import -r Test8.txt failed"
    echo ""
    exit 1
 fi
@@ -743,9 +746,9 @@ if ! grep -q "new paths:       1" /tmp/test8.out; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/list_files --md5 ?est8.txt > test8.md5; then
+if ! $EXEC/src/apps/file/file-list --md5 ?est8.txt > test8.md5; then
    echo ""
-   echo "list_files --md5 failed"
+   echo "file-list --md5 failed"
    echo ""
    exit 1
 fi
@@ -757,9 +760,9 @@ if ! md5sum -c test8.md5; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/list_files --sha1 ?est8.txt > test8.sha1; then
+if ! $EXEC/src/apps/file/file-list --sha1 ?est8.txt > test8.sha1; then
    echo ""
-   echo "list_files --sha1 failed"
+   echo "file-list --sha1 failed"
    echo ""
    exit 1
 fi
@@ -771,9 +774,9 @@ if ! sha1sum -c test8.sha1; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/list_files --sha256 ?est8.txt > test8.sha256; then
+if ! $EXEC/src/apps/file/file-list --sha256 ?est8.txt > test8.sha256; then
    echo ""
-   echo "list_files --sha256 failed"
+   echo "file-list --sha256 failed"
    echo ""
    exit 1
 fi
@@ -785,9 +788,9 @@ if ! sha256sum -c test8.sha256; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/list_files --sha512 ?est8.txt > test8.sha512; then
+if ! $EXEC/src/apps/file/file-list --sha512 ?est8.txt > test8.sha512; then
    echo ""
-   echo "list_files --sha512 failed"
+   echo "file-list --sha512 failed"
    echo ""
    exit 1
 fi
@@ -799,23 +802,23 @@ if ! sha512sum -c test8.sha512; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/verify_file ?est8.txt; then
+if ! $EXEC/src/apps/file/file-verify ?est8.txt; then
    echo ""
-   echo "verify_file failed"
+   echo "file-verify failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/verify_file --remove-no-shred ?est8.txt; then
+if ! $EXEC/src/apps/file/file-verify --remove-no-shred ?est8.txt; then
    echo ""
-   echo "verify_file failed"
+   echo "file-verify failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/export_file ?est8.txt; then
+if ! $EXEC/src/apps/file/file-export ?est8.txt; then
    echo ""
-   echo "export_file failed"
+   echo "file-export failed"
    echo ""
    exit 1
 fi
@@ -856,9 +859,9 @@ echo "--------------------------------------"
 echo "This is test #9" >> test9.txt
 echo "This is Test #9" >> Test9.txt
 
-if ! $EXEC/src/apps/file/import_file test9.txt Test9.txt > /tmp/test9.out; then
+if ! $EXEC/src/apps/file/file-import test9.txt Test9.txt > /tmp/test9.out; then
    echo ""
-   echo "import_file test9.txt failed"
+   echo "file-import test9.txt failed"
    echo ""
    exit 1
 fi
@@ -871,9 +874,9 @@ if ! grep -q "files created:   2" /tmp/test9.out; then
 fi
 
 
-if ! $EXEC/src/apps/file/list_files --md5 ?est9.txt > test9.md5; then
+if ! $EXEC/src/apps/file/file-list --md5 ?est9.txt > test9.md5; then
    echo ""
-   echo "list_files --md5 failed"
+   echo "file-list --md5 failed"
    echo ""
    exit 1
 fi
@@ -885,9 +888,9 @@ if ! md5sum -c test9.md5; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/list_files --sha1 ?est9.txt > test9.sha1; then
+if ! $EXEC/src/apps/file/file-list --sha1 ?est9.txt > test9.sha1; then
    echo ""
-   echo "list_files --sha1 failed"
+   echo "file-list --sha1 failed"
    echo ""
    exit 1
 fi
@@ -899,9 +902,9 @@ if ! sha1sum -c test9.sha1; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/list_files --sha256 ?est9.txt > test9.sha256; then
+if ! $EXEC/src/apps/file/file-list --sha256 ?est9.txt > test9.sha256; then
    echo ""
-   echo "list_files --sha256 failed"
+   echo "file-list --sha256 failed"
    echo ""
    exit 1
 fi
@@ -913,9 +916,9 @@ if ! sha256sum -c test9.sha256; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/list_files --sha512 ?est9.txt > test9.sha512; then
+if ! $EXEC/src/apps/file/file-list --sha512 ?est9.txt > test9.sha512; then
    echo ""
-   echo "list_files --sha512 failed"
+   echo "file-list --sha512 failed"
    echo ""
    exit 1
 fi
@@ -927,23 +930,23 @@ if ! sha512sum -c test9.sha512; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/verify_file ?est9.txt; then
+if ! $EXEC/src/apps/file/file-verify ?est9.txt; then
    echo ""
-   echo "verify_file failed"
+   echo "file-verify failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/verify_file --remove-no-shred ?est9.txt; then
+if ! $EXEC/src/apps/file/file-verify --remove-no-shred ?est9.txt; then
    echo ""
-   echo "verify_file failed"
+   echo "file-verify failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/export_file ?est9.txt; then
+if ! $EXEC/src/apps/file/file-export ?est9.txt; then
    echo ""
-   echo "export_file failed"
+   echo "file-export failed"
    echo ""
    exit 1
 fi
@@ -983,9 +986,9 @@ echo "--------------------------------------------------"
 
 echo "This is test #1" > test2.txt
 
-if $EXEC/src/apps/file/import_file --add-revision test2.txt > /tmp/test8r.out; then
+if $EXEC/src/apps/file/file-import --add-revision test2.txt > /tmp/test8r.out; then
    echo ""
-   echo "import_file --add-revision new file succeeded"
+   echo "file-import --add-revision new file succeeded"
    echo ""
    exit 1
 fi
@@ -1000,9 +1003,9 @@ fi
 
 echo "This is test #1" > test3.txt
 
-if $EXEC/src/apps/file/import_file --add-revision test2.txt > /tmp/test8r.out; then
+if $EXEC/src/apps/file/file-import --add-revision test2.txt > /tmp/test8r.out; then
    echo ""
-   echo "import_file --add-revision new file succeeded"
+   echo "file-import --add-revision new file succeeded"
    echo ""
    exit 1
 fi
@@ -1021,9 +1024,9 @@ echo "-------------------------------------------------"
 
 echo "This is test #3" > test3.txt
 
-if $EXEC/src/apps/file/import_file --add-revision test3.txt > /tmp/test3r.out; then
+if $EXEC/src/apps/file/file-import --add-revision test3.txt > /tmp/test3r.out; then
    echo ""
-   echo "import_file --add-revision new file succeeded"
+   echo "file-import --add-revision new file succeeded"
    echo ""
    exit 1
 fi
@@ -1040,9 +1043,9 @@ echo "---------------------------"
 echo " Case 12: revised file..."
 echo "---------------------------"
 
-if ! $EXEC/src/apps/file/import_file --add-revision test1.txt > /tmp/test1r.out; then
+if ! $EXEC/src/apps/file/file-import --add-revision test1.txt > /tmp/test1r.out; then
    echo ""
-   echo "import_file --add-revision failed"
+   echo "file-import --add-revision failed"
    echo ""
    exit 1
 fi
@@ -1054,37 +1057,37 @@ if ! grep -q "new revisions:   1" /tmp/test1r.out; then
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/verify_file test1.txt; then
+if ! $EXEC/src/apps/file/file-verify test1.txt; then
    echo ""
-   echo "verify_file revised file failed"
+   echo "file-verify revised file failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/verify_file --remove-no-shred test1.txt; then
+if ! $EXEC/src/apps/file/file-verify --remove-no-shred test1.txt; then
    echo ""
-   echo "verify_file --remove revised file failed"
+   echo "file-verify --remove revised file failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/export_file test1.txt; then
+if ! $EXEC/src/apps/file/file-export test1.txt; then
    echo ""
-   echo "export_file failed"
+   echo "file-export failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/verify_file test1.txt; then
+if ! $EXEC/src/apps/file/file-verify test1.txt; then
    echo ""
-   echo "verify_file revised file failed"
+   echo "file-verify revised file failed"
    echo ""
    exit 1
 fi
 
-if ! $EXEC/src/apps/file/verify_file --remove-no-shred test1.txt; then
+if ! $EXEC/src/apps/file/file-verify --remove-no-shred test1.txt; then
    echo ""
-   echo "verify_file --remove revised file failed"
+   echo "file-verify --remove revised file failed"
    echo ""
    exit 1
 fi
